@@ -253,7 +253,6 @@ gtr_gda_store_impl (GtrGda *self,
 {
   gint orig_id;
   gboolean found_translation = FALSE;
-  gchar *norm_translation = NULL;
   gchar **words = NULL;
   GError *inner_error;
 
@@ -270,9 +269,6 @@ gtr_gda_store_impl (GtrGda *self,
       return FALSE;
     }
 
-  norm_translation = g_utf8_normalize (translation, -1,
-                                       G_NORMALIZE_DEFAULT);
-
   if (orig_id == 0)
     {
       gsize sz, i;
@@ -314,7 +310,7 @@ gtr_gda_store_impl (GtrGda *self,
                                                               orig_id,
                                                               "value",
                                                               G_TYPE_STRING,
-                                                              norm_translation),
+                                                              translation),
                                           &inner_error);
       if (inner_error)
         goto error;
@@ -329,17 +325,15 @@ gtr_gda_store_impl (GtrGda *self,
                                       "orig_id", G_TYPE_INT,
                                       orig_id,
                                       "value", G_TYPE_STRING,
-                                      norm_translation),
+                                      translation),
                   &inner_error);
       if (inner_error)
         goto error;
     }
 
-  g_free (norm_translation);
   return TRUE;
 
  error:
-  g_free (norm_translation);
   g_strfreev (words);
   g_propagate_error (error, inner_error);
   return FALSE;
@@ -440,16 +434,12 @@ gtr_gda_remove (GtrTranslationMemory *tm,
                 const gchar *translation)
 {
   GtrGda *self = GTR_GDA (tm);
-  gchar *norm_translation;
   GdaSet *params;
   GError *error;
 
-  norm_translation = g_utf8_normalize (translation, -1,
-                                       G_NORMALIZE_DEFAULT);
-
   params = gda_set_new_inline (2,
                                "original", G_TYPE_STRING, original,
-                               "value", G_TYPE_STRING, norm_translation);
+                               "value", G_TYPE_STRING, translation);
 
   error = NULL;
   gda_connection_statement_execute_non_select (self->priv->db,
@@ -464,7 +454,6 @@ gtr_gda_remove (GtrTranslationMemory *tm,
     }
 
   g_object_unref (params);
-  g_free (norm_translation);
 }
 
 static void
@@ -775,38 +764,38 @@ gtr_gda_init (GtrGda * self)
                                                     GDA_CONNECTION_OPTIONS_NONE,
                                                     NULL);
 
-  gda_execute_non_select_command (self->priv->db,
-                                  "create table WORD ("
-                                  "ID integer primary key autoincrement,"
-                                  "VALUE text unique)",
-                                  NULL);
+  gda_connection_execute_non_select_command (self->priv->db,
+                                             "create table WORD ("
+                                             "ID integer primary key autoincrement,"
+                                             "VALUE text unique)",
+                                             NULL);
 
-  gda_execute_non_select_command (self->priv->db,
-                                  "create table WORD_ORIG_LINK ("
-                                  "WORD_ID integer,"
-                                  "ORIG_ID integer,"
-                                  "primary key (WORD_ID, ORIG_ID))",
-                                  NULL);
+  gda_connection_execute_non_select_command (self->priv->db,
+                                             "create table WORD_ORIG_LINK ("
+                                             "WORD_ID integer,"
+                                             "ORIG_ID integer,"
+                                             "primary key (WORD_ID, ORIG_ID))",
+                                             NULL);
 
-  gda_execute_non_select_command (self->priv->db,
-                                  "create table ORIG ("
-                                  "ID integer primary key autoincrement,"
-                                  "VALUE text unique,"
-                                  "SENTENCE_SIZE integer)",
-                                  NULL);
+  gda_connection_execute_non_select_command (self->priv->db,
+                                             "create table ORIG ("
+                                             "ID integer primary key autoincrement,"
+                                             "VALUE text unique,"
+                                             "SENTENCE_SIZE integer)",
+                                             NULL);
 
-  gda_execute_non_select_command (self->priv->db,
-                                  "create table TRANS ("
-                                  "ID integer primary key autoincrement,"
-                                  "ORIG_ID integer,"
-                                  "VALUE text)",
-                                  NULL);
+  gda_connection_execute_non_select_command (self->priv->db,
+                                             "create table TRANS ("
+                                             "ID integer primary key autoincrement,"
+                                             "ORIG_ID integer,"
+                                             "VALUE text)",
+                                             NULL);
 
-  gda_execute_non_select_command (self->priv->db,
-                                  "create index "
-                                  "if not exists IDX_TRANS_ORIG_ID "
-                                  "on TRANS (ORIG_ID)",
-                                  NULL);
+  gda_connection_execute_non_select_command (self->priv->db,
+                                             "create index "
+                                             "if not exists IDX_TRANS_ORIG_ID "
+                                             "on TRANS (ORIG_ID)",
+                                             NULL);
 
   /* prepare statements */
 
